@@ -69,9 +69,6 @@ GType                gpm_inhibit_applet_get_type  (void);
 #define GS_DBUS_PATH		"/org/gnome/SessionManager"
 #define GS_DBUS_INTERFACE	"org.gnome.SessionManager"
 
-static void      gpm_inhibit_applet_class_init (GpmInhibitAppletClass *klass);
-static void      gpm_inhibit_applet_init       (GpmInhibitApplet *applet);
-
 G_DEFINE_TYPE (GpmInhibitApplet, gpm_inhibit_applet, PANEL_TYPE_APPLET)
 
 static void	gpm_applet_update_icon		(GpmInhibitApplet *applet);
@@ -327,7 +324,7 @@ gpm_applet_dialog_about_cb (GtkAction *action, gpointer data)
 	gtk_about_dialog_set_translator_credits (about, translator_credits);
 	gtk_about_dialog_set_logo (about, logo);
 	gtk_about_dialog_set_license (about, license_trans);
-	gtk_about_dialog_set_website (about, "http://www.mate-desktop.org/");
+	gtk_about_dialog_set_website (about, "https://mate-desktop.org/");
 
 	gtk_window_set_icon_name (GTK_WINDOW (about), GPM_INHIBIT_APPLET_ICON_INHIBIT);
 
@@ -471,7 +468,7 @@ gpm_inhibit_applet_init (GpmInhibitApplet *applet)
 
 	/* Add application specific icons to search path */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
-                                           GPM_DATA G_DIR_SEPARATOR_S "icons");
+                                           GPM_ICONS_DATA);
 
 	/* monitor the daemon */
 	applet->bus_watch_id =
