@@ -1128,6 +1128,10 @@ static void
 gpm_stats_button_update_ui (void)
 {
 	UpDevice *device;
+
+	if (current_device == NULL)
+		return;
+
 	device = up_device_new ();
 	up_device_set_object_path_sync (device, current_device, NULL, NULL);
 	gpm_stats_update_info_data (device);
@@ -1186,11 +1190,7 @@ gpm_stats_window_activated_cb (GtkApplication *app, gpointer data)
  * gpm_stats_device_changed_cb:
  **/
 static void
-#if UP_CHECK_VERSION(0, 99, 0)
 gpm_stats_device_changed_cb (UpDevice *device, GParamSpec *pspec, gpointer user_data)
-#else
-gpm_stats_device_changed_cb (UpClient *client, UpDevice *device, gpointer user_data)
-#endif
 {
 	const gchar *object_path;
 	object_path = up_device_get_object_path (device);
@@ -1205,11 +1205,7 @@ gpm_stats_device_changed_cb (UpClient *client, UpDevice *device, gpointer user_d
  * gpm_stats_add_device:
  **/
 static void
-#if UP_CHECK_VERSION(0, 99, 0)
 gpm_stats_add_device (UpDevice *device, GPtrArray *devices)
-#else
-gpm_stats_add_device (UpDevice *device)
-#endif
 {
 	const gchar *id;
 	GtkTreeIter iter;
@@ -1218,13 +1214,11 @@ gpm_stats_add_device (UpDevice *device)
 	UpDeviceKind kind;
 	gchar *label, *vendor, *model;
 
-#if UP_CHECK_VERSION(0, 99, 0)
 	if (devices != NULL)
 		g_ptr_array_add (devices, device);
 
 	g_signal_connect (device, "notify",
 	                  G_CALLBACK (gpm_stats_device_changed_cb), NULL);
-#endif
 
 	/* get device properties */
 	g_object_get (device,
@@ -1266,38 +1260,25 @@ gpm_stats_data_changed_cb (UpClient *client, gpointer user_data)
  * gpm_stats_device_added_cb:
  **/
 static void
-#if UP_CHECK_VERSION(0, 99, 0)
 gpm_stats_device_added_cb (UpClient *client, UpDevice *device, GPtrArray *devices)
-#else
-gpm_stats_device_added_cb (UpClient *client, UpDevice *device, gpointer user_data)
-#endif
 {
 	const gchar *object_path;
 	object_path = up_device_get_object_path (device);
 	egg_debug ("added:     %s", object_path);
 
-#if UP_CHECK_VERSION(0, 99, 0)
 	gpm_stats_add_device (device, devices);
-#else
-	gpm_stats_add_device (device);
-#endif
 }
 
 /**
  * gpm_stats_device_removed_cb:
  **/
 static void
-#if UP_CHECK_VERSION(0, 99, 0)
 gpm_stats_device_removed_cb (UpClient *client, const gchar *object_path, GPtrArray *devices)
-#else
-gpm_stats_device_removed_cb (UpClient *client, UpDevice *device, gpointer user_data)
-#endif
 {
 	GtkTreeIter iter;
 	gchar *id = NULL;
 	gboolean ret;
 
-#if UP_CHECK_VERSION(0, 99, 0)
 	UpDevice *device_tmp;
 	guint i;
 
@@ -1308,9 +1289,6 @@ gpm_stats_device_removed_cb (UpClient *client, UpDevice *device, gpointer user_d
 			break;
 		}
 	}
-#else
-	const gchar *object_path = up_device_get_object_path (device);
-#endif
 	egg_debug ("removed:   %s", object_path);
 	if (g_strcmp0 (current_device, object_path) == 0) {
 		gtk_list_store_clear (list_store_info);
@@ -1338,9 +1316,9 @@ gpm_stats_history_type_combo_changed_cb (GtkWidget *widget, gpointer data)
 	guint active;
 	const gchar *axis_x = NULL;
 	const gchar *axis_y = NULL;
-	
+
 	active = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
-	
+
 	if (active == 0) {
 		history_type = GPM_HISTORY_RATE_VALUE;
 		/* TRANSLATORS: this is the X axis on the graph */
@@ -1390,9 +1368,9 @@ gpm_stats_type_combo_changed_cb (GtkWidget *widget, gpointer data)
 	guint active;
 	const gchar *axis_x = NULL;
 	const gchar *axis_y = NULL;
-	
+
 	active = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
-	
+
 	if (active == 0) {
 		stats_type = GPM_STATS_CHARGE_DATA_VALUE;
 		/* TRANSLATORS: this is the X axis on the graph for the whole battery device */
@@ -1440,9 +1418,9 @@ static void
 gpm_stats_range_combo_changed (GtkWidget *widget, gpointer data)
 {
 	guint active;
-	
+
 	active = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
-	
+
 	if (active == 0)
 		history_time = GPM_HISTORY_MINUTE_VALUE;
 	else if (active == 1)
@@ -1611,14 +1589,14 @@ main (int argc, char *argv[])
 
 	/* add application specific icons to search path */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
-                                           GPM_DATA G_DIR_SEPARATOR_S "icons");
+                                           GPM_ICONS_DATA);
 
 	/* get data from the settings */
 	settings = g_settings_new (GPM_SETTINGS_SCHEMA);
 
 	/* get UI */
 	builder = gtk_builder_new ();
-	retval = gtk_builder_add_from_file (builder, GPM_DATA "/gpm-statistics.ui", &error);
+	retval = gtk_builder_add_from_resource (builder, "/org/mate/powermanager/statistics/gpm-statistics.ui", &error);
 
 	if (error) {
 		egg_error ("failed to load ui: %s", error->message);
@@ -1677,6 +1655,12 @@ main (int argc, char *argv[])
 			  G_CALLBACK (gpm_stats_points_checkbox_stats_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "notebook1"));
+
+	gtk_widget_add_events (widget, GDK_SCROLL_MASK);
+	g_signal_connect (widget, "scroll-event",
+	                  G_CALLBACK (gpm_dialog_page_scroll_event_cb),
+	                  window);
+
 	page = g_settings_get_int (settings, GPM_SETTINGS_INFO_PAGE_NUMBER);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), page);
 	g_signal_connect (widget, "switch-page",
@@ -1780,13 +1764,7 @@ main (int argc, char *argv[])
 
 	wakeups = up_wakeups_new ();
 	g_signal_connect (wakeups, "data-changed", G_CALLBACK (gpm_stats_data_changed_cb), NULL);
-#if !UP_CHECK_VERSION(0, 99, 0)
-	/* coldplug */
-	ret = up_client_enumerate_devices_sync (client, NULL, NULL);
-	if (!ret)
-		goto out;
-#endif
-	devices = up_client_get_devices (client);
+	devices = up_client_get_devices2 (client);
 
 	/* add devices in visually pleasing order */
 	for (j=0; j<UP_DEVICE_KIND_LAST; j++) {
@@ -1794,24 +1772,14 @@ main (int argc, char *argv[])
 			device = g_ptr_array_index (devices, i);
 			g_object_get (device, "kind", &kind, NULL);
 			if (kind == j)
-#if UP_CHECK_VERSION(0, 99, 0)
 				/* NULL == do not add it to ptr array */
 				gpm_stats_add_device (device, NULL);
-#else
-				gpm_stats_add_device (device);
-#endif
 		}
 	}
 
 	/* connect now the coldplug is done */
-#if UP_CHECK_VERSION(0, 99, 0)
 	g_signal_connect (client, "device-added", G_CALLBACK (gpm_stats_device_added_cb), devices);
 	g_signal_connect (client, "device-removed", G_CALLBACK (gpm_stats_device_removed_cb), devices);
-#else
-	g_signal_connect (client, "device-added", G_CALLBACK (gpm_stats_device_added_cb), NULL);
-	g_signal_connect (client, "device-removed", G_CALLBACK (gpm_stats_device_removed_cb), NULL);
-	g_signal_connect (client, "device-changed", G_CALLBACK (gpm_stats_device_changed_cb), NULL);
-#endif
 
 	/* set current device */
 	if (devices->len > 0) {
@@ -1848,9 +1816,6 @@ main (int argc, char *argv[])
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_stats"));
 
 	status = g_application_run (G_APPLICATION (app), argc, argv);
-#if !UP_CHECK_VERSION(0, 99, 0)
-out:
-#endif
 	if (devices != NULL)
 		g_ptr_array_unref (devices);
 
